package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````I)L$"#0```!,SP```````#0`(``(
M`"@`'0`<``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(@&D`
M`(!I```%`````!````$`````<````/`$"`#P!`@D7@``L&X```8`````$```
M`@```!1P```4\`0(%/`$"/@```#X````!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%#E=&3P8P``\.,$"/#C!`C<````W`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````:````
M!````!0````#````1TY5`(1553@,WS1](P7BQ5VOO_WI[(WA80```&@`````
M```````````````[```````````````T`````````"H````]````&0``````
M```>````&````$T`````````#P```%4```!)````(P```&$```!=````*0``
M`#8```````````````X```!:````/@``````````````7````&8````H````
M-0````````!&````9P```#@````P`````````#(`````````90````````!%
M````0```````````````7@```!````!$````%0``````````````9````!T`
M```L````(```````````````+@`````````E``````````````!"````````
M``8````_````/````#D````A````2```````````````40```&(````F````
M!````#H````%````,0````````!#````````````````````2@```%D`````
M````)P```%8````D````00```$L````K`````````````````````````%0`
M`````````````````````````````$\```````````````(`````````````
M``````````````````````!3````$0```!(`````````````````````````
M3``````````,```````````````;````8````%<```!?`````````!0```!8
M`````````%L````````````````````:````!P````@`````````$P```"\`
M````````````````````````%P```````````````0```%(`````````````
M`%`````W````'````&,````````````````````?````````````````````
M````````````````+0````L```````````````````````````````D`````
M````````````````````3@``````````````(@```!8`````````1P``````
M````````````````````````,P`````````#````#0````H````E````0P``
M``@````(`````!P0!"5`!((X`4`!HH8!J$````)+*`0I.*(R1XH$#`A#````
M10```````````````````$<```!)````2@````````!+````3````$X```!/
M````4````%$`````````4@``````````````4P```%0```!7````````````
M``!8````6@```%L```!=`````````%\```!A``````````````!C````9```
M`&4`````````R-6R<5GH[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!
M5J2;EFL)0]8Y\HL<#3J7"\6)!9`-%.*>(?_D#@N*$%?$N9Q`:G^:?+,!BV]_
MJ9R;;L7?']EQ6!R[XY)\K$OCP-5DU'S@IP(*,V+;[7KP2FMGK\QF0D75[.-'
MQ@%]08[%P^4_+/+;TQWZH6Q@N8WQ#@````````````````````#6`@``````
M```````2````6P,`````````````$@```"X"`````````````!(```#7`P``
M```````````2````3`,`````````````$@````<!`````````````!(```#C
M`@`````````````2````G0``````````````$@```-T"`````````````!(`
M``!Y```````````````2`````@$`````````````$@```(T"````````````
M`!(````<`P`````````````2````G@(`````````````$@```&L!````````
M`````!(````L`P`````````````2````(P,`````````````$@```"L!````
M`````````!(```"K```````````````2````M0$`````````````$@```%(!
M`````````````!(```!,`@`````````````2````)@(`````````````$@``
M`+H"`````````````!(```"B`0`````````````2````JP(`````````````
M$@```*X!`````````````!(````Y`0`````````````2````$0``````````
M````(````%X"`````````````!(````S`P`````````````2````0@``````
M````````$@```,@"`````````````!(```!B`P`````````````2````.@,`
M````````````$@````X"`````````````!(```#9```````````````2````
MB```````````````$@```&`!`````````````!(```#/`@`````````````2
M````I0(`````````````$@```',"`````````````!(````5`@``````````
M```2````LP(`````````````$@```#0``````````````!(```"%`@``````
M```````2````#`$`````````````$@```)<!`````````````!(```#F````
M```````````2````5`,`````````````$@```,$"`````````````!(```!Y
M`0`````````````2````(```````````````(````+T``````````````!(`
M``!)`0`````````````2````8P(`````````````$@```$(#````````````
M`!(```!1```````````````2````:P(`````````````$@```/T"````````
M`````!(```#T`0`````````````2````Z@(`````````````$@````@"````
M`````````!(```!\`@`````````````2````]0(`````````````$@````<#
M`````````````!(````8`0``,)@$"``````2````100``*C@!`@$````$0`0
M``4$``!`SP0(A0L``!(`#@!,!```,,P$")\!```2``X`K@,``(S@!`@`````
M$@`/`'8#``!`3@4(!````"$`&@"T`P``0,D$"`4````2``X`-00```#@!`A:
M````$@`.`&@```#@F`0(`````!(```#W````2$X%"`0````1`!H`$@0``$#R
M!`@`````$``9`!4#``!$3@4(!````!$`&@`4!```0/($"``````@`!D`=0,`
M`$!.!0@$````(0`:`*0#``#PWP0(!0```!(`#@!A!```4,D$"+0!```2``X`
MS````$Q.!0@!````$0`:`'0#``!`3@4(!````!$`&@!O`P``P)D$".(!```2
M``X`@`0``-#-!`A"````$@`.`,4#```@S@0()````!(`#@#@`P``X-X$"'@`
M```2``X`DP,``"1.!0@`````$`#Q_Y\#``"P7@4(`````!``\?\]`@``K.`$
M"`0````1`!``J@0``-#:!`@+!```$@`.`!\$``!PR`0(S@```!(`#@`8!```
MI)L$"``````2``X`AP$```"6!`@`````$@```/D#``!`RP0(X@```!(`#@",
M`P``)$X%"``````0`/'_[`,``!#+!`@O````$@`.`(X$``!@WP0(20```!(`
M#@!9!```T,<$"#0````2``X`P`$``$U.!0@3````$0`:`&X$``!0S@0(\```
M`!(`#@!;!```-)4$"``````2``P``&QI8G!E<FPN<V\N-2XQ-`!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`
M4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`
M;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC
M`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L
M:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI
M=`!S<')I;G1F`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`<W1R;F-P>0!?
M7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G
M971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P
M>0!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``<W1R8VAR`&9P<FEN=&8`
M<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?
M;6%I;@!?7V5N=FER;VX`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A
M<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA
M;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`%]F<%]H=P!P87)?
M:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`
M6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)
M0D-?,BXS`$=,24)#7S(N,RXR`$=,24)#7S(N-`````(``@`#``(``@`"``(`
M```"```````$``(``@````(``@````````````4`!@`"`````@`"```````"
M``(````"``(``@`&``````````(``@`"``,``@````(``````````@`"````
M`````````@`'`````@`'``,`!P`#``(``@`(`````0`!``$``0`"``$``0``
M`````0`"``$``@`!``$````"``$``0`!``$``0`!``$``0`!``$````!``$`
M`0`!``$````!``$``0`"`.0!```0````,````!)I:0T```8`P`0``!`````0
M:6D-```#`,H$`````````0`%`#,"```0`````````!-I:0T```@`U`0``!``
M```2:6D-```'`,`$```0````<AEI"0``!0#>!```$````!1I:0T```0`Z@0`
M`!`````0:6D-```"`,H$````````#/$$"`8=``!`3@4(!50``$1.!0@%3@``
M2$X%"`5,``!,3@4(!5,``$U.!0@%90``'/$$"`<!```@\00(!P(``"3Q!`@'
M`P``*/$$"`<$```L\00(!P4``##Q!`@'!@``-/$$"`<'```X\00(!P@``#SQ
M!`@'7P``0/$$"`<)``!$\00(!PH``$CQ!`@'"P``3/$$"`<,``!0\00(!PT`
M`%3Q!`@'#@``6/$$"`</``!<\00(!Q```&#Q!`@'$0``9/$$"`<2``!H\00(
M!Q,``&SQ!`@'%```</$$"`<5``!T\00(!Q8``'CQ!`@'%P``?/$$"`<8``"`
M\00(!QD``(3Q!`@'&@``B/$$"`<;``",\00(!QP``)#Q!`@''0``E/$$"`<>
M``"8\00(!Q\``)SQ!`@'(```H/$$"`<A``"D\00(!R(``*CQ!`@'(P``K/$$
M"`<D``"P\00(!R4``+3Q!`@')@``N/$$"`<G``"\\00(!R@``,#Q!`@'*0``
MQ/$$"`<J``#(\00(!T,``,SQ!`@'*P``T/$$"`<L``#4\00(!RT``-CQ!`@'
M+@``W/$$"`<O``#@\00(!S```.3Q!`@',0``Z/$$"`<R``#L\00(!S,``/#Q
M!`@'-```]/$$"`=+``#X\00(!S8``/SQ!`@'-P```/($"`<X```$\@0(!SD`
M``CR!`@'.@``#/($"`<[```0\@0(!SP``!3R!`@'/0``&/($"`<^```<\@0(
M!S\``"#R!`@'0```)/($"`=!```H\@0(!T(``%6)Y5.#[`3H`````%N!P]!;
M``"+D_S___^%TG0%Z/H!``#HU08``.@`2P``6%O)PP```````````````/\U
M%/$$"/\E&/$$"`````#_)1SQ!`AH`````.G@_____R4@\00(:`@```#IT/__
M__\E)/$$"&@0````Z<#_____)2CQ!`AH&````.FP_____R4L\00(:"````#I
MH/____\E,/$$"&@H````Z9#_____)33Q!`AH,````.F`_____R4X\00(:#@`
M``#I</____\E//$$"&A`````Z6#_____)4#Q!`AH2````.E0_____R5$\00(
M:%````#I0/____\E2/$$"&A8````Z3#_____)4SQ!`AH8````.D@_____R50
M\00(:&@```#I$/____\E5/$$"&AP````Z0#_____)5CQ!`AH>````.GP_O__
M_R5<\00(:(````#IX/[___\E8/$$"&B(````Z=#^____)63Q!`AHD````.G`
M_O___R5H\00(:)@```#IL/[___\E;/$$"&B@````Z:#^____)7#Q!`AHJ```
M`.F0_O___R5T\00(:+````#I@/[___\E>/$$"&BX````Z7#^____)7SQ!`AH
MP````.E@_O___R6`\00(:,@```#I4/[___\EA/$$"&C0````Z4#^____)8CQ
M!`AHV````.DP_O___R6,\00(:.````#I(/[___\ED/$$"&CH````Z1#^____
M)93Q!`AH\````.D`_O___R68\00(:/@```#I\/W___\EG/$$"&@``0``Z>#]
M____):#Q!`AH"`$``.G0_?___R6D\00(:!`!``#IP/W___\EJ/$$"&@8`0``
MZ;#]____):SQ!`AH(`$``.F@_?___R6P\00(:"@!``#ID/W___\EM/$$"&@P
M`0``Z8#]____);CQ!`AH.`$``.EP_?___R6\\00(:$`!``#I8/W___\EP/$$
M"&A(`0``Z5#]____)<3Q!`AH4`$``.E`_?___R7(\00(:%@!``#I,/W___\E
MS/$$"&A@`0``Z2#]____)=#Q!`AH:`$``.D0_?___R74\00(:'`!``#I`/W_
M__\EV/$$"&AX`0``Z?#\____)=SQ!`AH@`$``.G@_/___R7@\00(:(@!``#I
MT/S___\EY/$$"&B0`0``Z<#\____)>CQ!`AHF`$``.FP_/___R7L\00(:*`!
M``#IH/S___\E\/$$"&BH`0``Z9#\____)?3Q!`AHL`$``.F`_/___R7X\00(
M:+@!``#I</S___\E_/$$"&C``0``Z6#\____)0#R!`AHR`$``.E0_/___R4$
M\@0(:-`!``#I0/S___\E"/($"&C8`0``Z3#\____)0SR!`AHX`$``.D@_/__
M_R40\@0(:.@!``#I$/S___\E%/($"&CP`0``Z0#\____)1CR!`AH^`$``.GP
M^____R4<\@0(:``"``#IX/O___\E(/($"&@(`@``Z=#[____)23R!`AH$`(`
M`.G`^____R4H\@0(:!@"``#IL/O__U6)Y593@^3P@^PPC440B40D"(U%#(E$
M)`2-10B)!"3HG/W__\=$)`@PF`0(QT0D!#"8!`C'!"3@F`0(Z+!%``"`/4Q.
M!0@`=2[HLOS__X7`HZQ>!0@/A'L!``")!"3H_?O__Z%(3@4(B00DZ##____&
M@``#````H4A.!0@QVXD$).@:____@(A#`P```J%(3@4(B00DZ`;___^+50B#
MP@6`B$,#```!B50D*(E<)"S?;"0HV`7@XP0(W07HXP0(V<G:Z=_@G@^']@``
M`,'B`HD4).AY_/__BW4,BUT(QP6D7@4(!````(L6@_L!HZ!>!0C'0`25X@0(
MB1#'0`B`\@0(QT`,F.($"'X4N@$```"0BPR6B4R0#(/"`3G:=?*#PP/'!)@`
M````B40D#*&L7@4(B5PD",=$)!``````QT0D!!#(!`B)!"3H@_W__X7`B<-T
M-J&L7@4(B00DZ%#[__^X6>$$".C6)0``A<!T+*&L7@4(B00DZ/7Z___H(/W_
M_XUE^(G86UY=PZ&L7@4(B00DZ*K]__^)P^NYH:A>!0B%P'0*B00DZ'5#``#K
MP;@.X00(Z(DE``"%P*.H7@4(=*[KX<=$)`1-3@4(QP0D">$$".A*_/__QP0D
M`0```.B^^___D)`Q[5Z)X8/D\%!44FCPWP0(:`#@!`A15FC`F00(Z-O[___T
MD)"0D)"0D)"0D%6)Y5.#[`2`/6!.!0@`=3^A9$X%"+L,\`0(@>L(\`0(P?L"
M@^L!.=AS'HVV`````(/``:-D3@4(_Q2%"/`$"*%D3@4(.=ARZ,8%8$X%"`&#
MQ`1;7<.-="8`C;PG`````%6)Y8/L&*$0\`0(A<!T$K@`````A<!T"<<$)!#P
M!`C_T,G#D)"0D)"0D)"0D)"0D%6)Q5>#Q3A64S';@>SD`@``B40D5(UV`(MT
MG0"+?)T$QT3<9`````#'1-QL`````(GPP>`(B?J)P8GPP>`8@>$``/\`"<&)
M\`^LT`B)^B4`_P``"<&)\`^LT!B)_B7_````,?\)P8GPP>`(B?J)3-Q@B<&)
M\,'@&('A``#_``G!B?`/K-`(B?HE`/\```G!B?`/K-`8)?\````)P8E,W&B#
MPP*#^Q`/A6S___^-C"3(````C9PDR`(``(VV`````(M1V(M!W(MQF(MYG#,1
M,T$$,U&H,T&LQT$<`````#'6,<>)\(GZ#ZS0'XE$)"B)\`'`"T0D*,'J'XE4
M)"R)01B#P0@YV76YBTPD5(MT)%2+;"14BQ&+7@B+202+?1")5"0@BU0D5(E<
M)!B+7"14BW8,B4PD)(MM%(M"&(M+((ET)!R+="0@B7PD$(M\)"2)1"0(BU(<
MB<B+6R0#1"1@B0PDB6PD%(ML)!`%F7F"6@^L_AN+?"0@B?&+="04B50D#(E<
M)`3!YP4)^0'(BTPD&"-T)!PC;"08]]$C3"0(B70D*(M4)!R+7"0@B<Z+3"08
M">X!\#'_B<:+1"08P>$>QT0D1`````#'1"0\``````^LT`*+5"0DB<6+1"0(
M"<V+3"0@`T0D:(EL)$`%F7F"6O?1(TPD$"'KBVPD)`G+B?&)7"0HB?OWU2-L
M)!0#1"0H#ZS9&XE,)"B)\<'A!8E,)#"+3"0H"TPD,(EL)"S'1"0L``````'(
MBTPD((E$)"B+1"0@P>$>#ZS0`HGZB<6+1"00"<V)\0-$)'#WT8GKB6PD.`69
M>8):(?,C3"1`"=F)3"0PQT0D-`````"+7"0LBTPD*`-$)##'1"0T`````(M\
M)#3'1"1,``````^LV1N)3"0PBTPD*,=$)$0`````P>$%B4PD2(M,)#`+3"1(
M`<B+3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$)$`)\_?1`T0D>(E<)$B+7"0H
M!9EY@EHAZ2-<)$B)S@G>BUPD,`'PBW0D,`^L_AN+?"0PB?'!YP4)^0'(BTPD
M*#'_B<:+1"0HP>$>#ZS0`HG%BT0D.`G-BTPD,`.$)(````");"1`!9EY@EKW
MT2-,)$@AZPG9B?N)3"0HB?&+5"0T`T0D*`^LV1N)3"0HB?'!X06)3"0XBTPD
M*`M,)#C'1"0L`````,=$)"P``````<B+3"0PB40D*(M$)##'1"0T`````,=$
M)#0`````P>$>#ZS0`HGZBWPD-(G%BT0D2`G-B?$#A"2(````]]&)ZXEL)#@%
MF7F"6B'S(TPD0,=$)#P`````QT0D3``````)V8M<)"R)3"0PBTPD*`-$)#`/
MK-D;B4PD,(M,)"C!X06)3"1(BTPD,`M,)$@!R(M,)"B)1"0PB?`/K-`"BU0D
M+,'F'HG#BT0D0`GS]]$#A"20````B5PD2(M<)"@%F7F"6B'I(UPD2(G."=X!
M\(MT)#`/K/X;BWPD,(GQP><%"?D!R(M,)"@Q_XG&BT0D*,'A'@^LT`*)Q0G-
MB6PD0(M$)#B+3"0P`X0DF````(M<)#"+5"0T!9EY@EKWT2-,)$@AZ\=$)"P`
M````"=F)^XE,)"B)\0-$)"@/K-D;B4PD*(GQP>$%B4PD.(M,)"@+3"0XQT0D
M+`````#'1"1$``````'(BTPD,(E$)"B+1"0PQT0D/`````#'1"0T`````,'A
M'@^LT`*)^HG%BT0D2`G-B?$#A"2@````]]&)ZXEL)#@%F7F"6B'S(TPD0`G9
MBUPD+(E,)#"+3"0H`T0D,`^LV1N)3"0PBTPD*,'A!8E,)$B+3"0P"TPD2,=$
M)#0`````BWPD-,=$)$P``````<B+3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$
M)$`)\_?1`X0DJ````(E<)$B+7"0HQT0D1``````%F7F"6B'I(UPD2(G.QT0D
M+``````)WHM<)#`!\(MT)#`/K/X;BWPD,(GQP><%"?D!R(M,)"@Q_XG&BT0D
M*,'A'@^LT`*)Q8M$)#@)S8M,)#`#A"2P````B6PD0`69>8):]]$C3"1((>L)
MV8G[B4PD*(GQ`T0D*`^LV1N)3"0HB?'!X06)3"0XBTPD*`M,)#@!R(E$)"B+
M1"0PBU0D-(M,)##'1"0L`````,=$)#0`````#ZS0`HGZP>$>B<6+1"1("<V)
M\0.$)+@```#WT8GKQT0D-`````"+?"0T!9EY@EHA\R-,)$");"0XQT0D/```
M```)V8M<)"R)3"0PBTPD*`-$)##'1"1,``````^LV1N)3"0PBTPD*,'A!8E,
M)$B+3"0P"TPD2`'(BTPD*(E$)#")\`^LT`*+5"0LP>8>B<.+1"1`"?/WT0.$
M),````")7"1(BUPD*`69>8):(>DC7"1(B<X)W@'PBW0D,`^L_AN+?"0PB?'!
MYP4)^0'(BTPD*#'_B<:+1"0HP>$>#ZS0`HG%"<V);"1`BT0D.(M,)#`#A"3(
M````BUPD,(M4)#0%F7F"6O?1(TPD2"'KQT0D+``````)V8G[B4PD*(GQ`T0D
M*`^LV1N)3"0HB?'!X06)3"0XBTPD*`M,)#C'1"0L`````,=$)$0``````<B+
M3"0PB40D*(M$)##'1"0\`````,=$)#0`````P>$>#ZS0`HGZB<6+1"1("<V)
M\0.$)-````#WT8GKB6PD.`69>8):(?,C3"1`"=F+7"0LB4PD,(M,)"@#1"0P
M#ZS9&XE,)#"+3"0HP>$%B4PD2(M,)#`+3"1(QT0D-`````"+?"0TQT0D3```
M```!R(M,)"B)1"0PB?`/K-`"BU0D+,'F'HG#BT0D0`GS]]$#A"38````B5PD
M2(M<)"C'1"1$``````69>8):(>DC7"1(B<['1"0L``````G>BUPD,`'PBW0D
M,`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HP>$>#ZS0`HG%BT0D.`G-
MBTPD,`.$).````");"1`!9EY@EKWT2-,)$@AZPG9B?N)3"0HB?$#1"0H#ZS9
M&XE,)"B)\<'A!8E,)#B+3"0H"TPD.`'(B40D*(M$)#"+5"0TBTPD,,=$)"P`
M````QT0D-``````/K-`"B?K!X1Z)Q8M$)$@)S8GQ`X0DZ````/?1B>O'1"0T
M`````(M\)#0%F7F"6B'S(TPD0(EL)#C'1"0\``````G9BUPD+(E,)#"+3"0H
M`T0D,,=$)$P`````#ZS9&XE,)#"+3"0HP>$%B4PD2(M,)#`+3"1(`<B+3"0H
MB40D,(GP#ZS0`HM4)"S!YAZ)PXM$)$`)\_?1`X0D\````(E<)$B+7"0H!9EY
M@EHAZ2-<)$B)S@G>`?"+="0P#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$
M)"C!X1X/K-`"B<4)S8EL)$"+1"0XBTPD,`.$)/@```"+7"0PBU0D-`69>8):
M]]$C3"1((>O'1"0L``````G9B?N)3"0HB?$#1"0H#ZS9&XE,)"B)\<'A!8E,
M)#B+3"0H"TPD.,=$)"P`````BUPD+,=$)$0``````<B+3"0PB40D*(M$)##'
M1"0\`````,'A'@^LT`*)^HG%BT0D2`G-`X0D``$``(EL)#@%H>O9;C-L)$")
MZ3'Q`<B+3"0H#ZS9&XE,)#"+3"0HP>$%B4PD2(M,)#`+3"1(`<B)1"0PB?"+
M3"0H#ZS0`HM4)"S!YAZ)PXM$)$`)\XMT)#@#A"0(`0``QT0D-`````"+?"0T
MB5PD2`6AZ]EN,=XQ\8MT)#`!R,=$)"P`````QT0D3``````/K/X;BWPD,(GQ
MQT0D1`````#'1"0\`````,'G!0GY`<B+3"0H,?^)QHM$)"B)^\'A'@^LT`*+
M5"0TB<6+1"0X"<V+3"0P`X0D$`$``(EL)$`%H>O9;C-L)$@QZ0'(B?$/K-D;
MBUPD+(E,)"B)\<'A!8E,)#B+3"0H"TPD.`'(BTPD,(E$)"B+1"0PP>$>#ZS0
M`HGZB<6+1"1("<T#A"08`0``B6PD.`6AZ]EN,VPD0(GI,?$!R(M,)"@/K-D;
MB4PD,(M,)"C'1"0T`````(M\)#3'1"1,`````,=$)$0`````P>$%B4PD2(M,
M)#`+3"1(`<B+3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$)$`)\XMT)#@#A"0@
M`0``B5PD2,=$)"P`````!:'KV6XQWC'QBW0D,`'(#ZS^&XM\)#")\<'G!0GY
M`<B+3"0H,?^)QHM$)"B)^\'A'@^LT`*+5"0TB<6+1"0X"<V+3"0P`X0D*`$`
M`(EL)$`%H>O9;C-L)$@QZ0'(B?$/K-D;B4PD*(GQP>$%B4PD.(M,)"@+3"0X
M`<B+3"0PB40D*(M$)##!X1X/K-`"B?J)Q0G-B6PD.(M$)$@#A"0P`0``BUPD
M+,=$)#0`````BWPD-`6AZ]EN,VPD0,=$)#P`````QT0D3`````")Z3'Q`<B+
M3"0HQT0D1``````/K-D;B4PD,(M,)"C!X06)3"1(BTPD,`M,)$@!R(M,)"B)
M1"0PB?`/K-`"BU0D+,'F'HG#BT0D0`GSBW0D.`.$)#@!``")7"1(!:'KV6XQ
MWC'QBW0D,`'(#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$)"B)^\'A'@^L
MT`*)Q8M$)#@)S8M,)#`#A"1``0``B6PD0`6AZ]EN,VPD2#'I`<B)\0^LV1N)
M3"0HB?&+5"0TP>$%B4PD.(M,)"@+3"0XQT0D+`````"+7"0LQT0D-``````!
MR(M,)#")1"0HBT0D,,=$)#P`````QT0D3`````#!X1X/K-`"B?J+?"0TB<6+
M1"1("<T#A"1(`0``B6PD.`6AZ]EN,VPD0(GI,?$!R(M,)"@/K-D;B4PD,(M,
M)"C!X06)3"1(BTPD,`M,)$@!R(M,)"B)1"0PB?`/K-`"BU0D+,'F'HG#BT0D
M0`GSBW0D.`.$)%`!``")7"1(!:'KV6XQWC'QBW0D,`'(#ZS^&XM\)#")\<'G
M!0GY`<B+3"0H,?^)QHM$)"B)^\'A'@^LT`*)Q0G-B6PD0(M$)#@#A"18`0``
MBTPD,(M4)#0%H>O9;C-L)$C'1"0L`````,=$)#0`````,>D!R(GQ#ZS9&XM<
M)"R)3"0HB?'!X06)3"0XBTPD*`M,)#C'1"1$`````,=$)#P``````<B+3"0P
MB40D*(M$)##'1"1,`````,'A'@^LT`*)^HM\)#2)Q8M$)$@)S0.$)&`!``")
M;"0X!:'KV6XS;"1`B>DQ\0'(BTPD*`^LV1N)3"0PBTPD*,'A!8E,)$B+3"0P
M"TPD2`'(BTPD*(E$)#")\`^LT`*+5"0LP>8>B<.+1"1`"?.+="0X`X0D:`$`
M`(E<)$@%H>O9;C'>,?&+="0P`<@/K/X;BWPD,(GQP><%"?D!R(M,)"@Q_XG&
MBT0D*(G[P>$>#ZS0`HG%"<V);"1`BT0D.`.$)'`!``"+3"0PBU0D-`6AZ]EN
M,VPD2,=$)"P`````QT0D-``````QZ0'(B?$/K-D;BUPD+(E,)"B)\<'A!8E,
M)#B+3"0H"TPD.,=$)$0`````QT0D/``````!R(M,)#")1"0HBT0D,,=$)$P`
M````P>$>#ZS0`HGZBWPD-(G%BT0D2`G-`X0D>`$``(EL)#@%H>O9;C-L)$")
MZ3'Q`<B+3"0H#ZS9&XE,)#"+3"0HP>$%B4PD2(M,)#`+3"1(`<B+3"0HB40D
M,(GP#ZS0`HM4)"S!YAZ)PXM$)$`)\XMT)#@#A"2``0``B5PD2`6AZ]EN,=XQ
M\8MT)#`!R`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HB?O!X1X/K-`"
MB<4)S8EL)$"+1"0X`X0DB`$``(M,)#"+5"0T!:'KV6XS;"1(QT0D+`````#'
M1"0T`````#'I`<B)\0^LV1N+7"0LB4PD*(GQP>$%B4PD.(M,)"@+3"0XQT0D
M1`````#'1"1<``````'(BTPD,(E$)"B+1"0PQT0D/`````#!X1X/K-`"B?J+
M?"0TB<6+1"1("<T#A"20`0``B6PD6`6AZ]EN,VPD0(GI,?$!R(M,)"@/K-D;
MB4PD,(M,)"C!X06)3"0XBTPD,`M,)#@!R(M,)"B)1"0PB?`/K-`"BU0D+,'F
M'HG#BT0D0`GSBW0D6`.$))@!``")7"0X!:'KV6XQWC'QBW0D,`'(#ZS^&XM\
M)#")\<'G!0GY`<B+3"0H,?^)QHM$)"C!X1X/K-`"B<4)S8EL)"B+3"0XBT0D
M6`.$)*`!``"+7"0XBU0D-`7<O!N/">DC3"0P(>O'1"1$``````G9B?N)3"1`
MB?$#1"1`#ZS9&XM<)"B)3"1`B?'!X06)3"1(BTPD0`M,)$C'1"1$`````,=$
M)"P``````<B+3"0PB40D0(M$)##'1"0T`````,=$)#P`````P>$>#ZS0`HGZ
MB<6+1"0X"<V+3"0H`X0DJ`$``(EL)#`%W+P;CPGI(>LA\0G9BUPD1(E,)#B+
M3"1``T0D.`^LV1N)3"0XBTPD0,=$)#P`````BWPD/,=$)$P`````QT0D+```
M``#!X06)3"1(BTPD.`M,)$C'1"0T``````'(B40D.(GP#ZS0`HM4)$3!YAZ)
MPXM$)"@)\P.$)+`!``")V8E<)$@%W+P;CPGI(TPD0"'KB<X)WHM<)$@!\(MT
M)#@/K/X;BWPD.(GQP><%"?D!R(M,)$`Q_XG&BT0D0,'A'@^LT`*)Q8M$)#`)
MS8M,)$@#A"2X`0``B6PD*`7<O!N/">DC3"0X(>L)V8G[B4PD,(GQ`T0D,`^L
MV1N)3"0PB?'!X06)3"1`BTPD,`M,)$`!R(E$)#"+1"0XBU0D/(M,)#B+7"0H
MQT0D-``````/K-`"B?K!X1Z)Q8M$)$@)S8M,)"@#A"3``0``QT0D/`````#'
M1"0\`````(M\)#P%W+P;CPGI(>LA\0G9BUPD-(E,)#B+3"0P`T0D.(EL)$#'
M1"1$``````^LV1N)3"0XBTPD,,=$)$P`````P>$%B4PD2(M,)#@+3"1(`<B)
M1"0XB?`/K-`"BU0D-,'F'HG#BT0D*`GS`X0DR`$``(G9B5PD2`7<O!N/">DC
M3"0P(>N)S@G>`?"+="0X#ZS^&XM\)#B)\<'G!0GY`<B+3"0P,?^)QHM$)##!
MX1X/K-`"B<4)S8EL)"B+1"1`BTPD2`.$)-`!``"+7"1(BU0D/`7<O!N/">DC
M3"0X(>O'1"0T``````G9B?N)3"0PB?$#1"0P#ZS9&XM<)"B)3"0PB?'!X06)
M3"1`BTPD,`M,)$#'1"0T`````,=$)"P``````<B+3"0XB40D,(M$)#C'1"1$
M`````,=$)#P`````P>$>#ZS0`HGZB<6+1"1("<V+3"0H`X0DV`$``(EL)$`%
MW+P;CPGI(>LA\0G9BUPD-(E,)#B+3"0P`T0D.`^LV1N)3"0XBTPD,,=$)#P`
M````BWPD/,=$)$P`````QT0D+`````#!X06)3"1(BTPD.`M,)$@!R(E$)#B)
M\`^LT`*+5"0TP>8>B<.+1"0H"?,#A"3@`0``B=F)7"1(QT0D-``````%W+P;
MCPGI(TPD,"'KB<X)WHM<)$@!\(MT)#@/K/X;BWPD.(GQP><%"?D!R(M,)#`Q
M_XG&BT0D,,'A'@^LT`*)Q8M$)$`)S8M,)$@#A"3H`0``B6PD*`7<O!N/">DC
M3"0X(>L)V8G[B4PD,(GQ`T0D,`^LV1N)3"0PB?'!X06)3"1`BTPD,`M,)$`!
MR(E$)#"+1"0XBU0D/(M,)#B+7"0HQT0D-``````/K-`"B?K!X1Z)Q8M$)$@)
MS8M,)"@#A"3P`0``QT0D/`````#'1"0\`````(M\)#P%W+P;CPGI(>LA\0G9
MBUPD-(E,)#B+3"0P`T0D.(EL)$#'1"1$``````^LV1N)3"0XBTPD,,=$)$P`
M````P>$%B4PD2(M,)#@+3"1(`<B)1"0XB?`/K-`"BU0D-,'F'HG#BT0D*`GS
M`X0D^`$``(G9B5PD2`7<O!N/">DC3"0P(>N)S@G>`?"+="0X#ZS^&XM\)#B)
M\<'G!0GY`<B+3"0P,?^)QHM$)##!X1X/K-`"B<4)S8EL)"B+1"1`BTPD2`.$
M)``"``"+7"1(BU0D/`7<O!N/">DC3"0X(>O'1"0T``````G9B?N)3"0PB?$#
M1"0P#ZS9&XM<)"B)3"0PB?'!X06)3"1`BTPD,`M,)$#'1"0T`````,=$)"P`
M`````<B+3"0XB40D,(M$)#C'1"1$`````,=$)#P`````P>$>#ZS0`HGZB<6+
M1"1("<V+3"0H`X0D"`(``(EL)$`%W+P;CPGI(>LA\0G9BUPD-(E,)#B+3"0P
M`T0D.`^LV1N)3"0XBTPD,,=$)#P`````BWPD/,=$)$P`````QT0D+`````#!
MX06)3"1(BTPD.`M,)$@!R(E$)#B)\`^LT`*+5"0TP>8>B<.+1"0H"?,#A"00
M`@``B=F)7"1(QT0D-``````%W+P;CPGI(TPD,"'KB<X)WHM<)$@!\(MT)#@/
MK/X;BWPD.(GQP><%"?D!R(M,)#`Q_XG&BT0D,,'A'@^LT`*)Q8M$)$`)S8M,
M)$@#A"08`@``B6PD*`7<O!N/">DC3"0X(>L)V8G[B4PD,(GQ`T0D,`^LV1N)
M3"0PB?'!X06)3"1`BTPD,`M,)$`!R(E$)#"+1"0XBU0D/(M,)#B+7"0HQT0D
M-``````/K-`"B?K!X1Z)Q8M$)$@)S8M,)"@#A"0@`@``QT0D/`````#'1"0\
M`````(M\)#P%W+P;CPGI(>LA\0G9BUPD-(E,)#B+3"0P`T0D.(EL)$#'1"1$
M``````^LV1N)3"0XBTPD,,=$)$P`````P>$%B4PD2(M,)#@+3"1(`<B)1"0X
MB?`/K-`"BU0D-,'F'HG#BT0D*`GS`X0D*`(``(G9B5PD2`7<O!N/">DC3"0P
M(>N)S@G>`?"+="0X#ZS^&XM\)#B)\<'G!0GY`<B+3"0P,?^)QHM$)##!X1X/
MK-`"B<4)S8EL)"B+1"1`BTPD2`.$)#`"``"+7"1(BU0D/`7<O!N/">DC3"0X
M(>O'1"0T``````G9B?N)3"0PB?$#1"0P#ZS9&XM<)"B)3"0PB?'!X06)3"1`
MBTPD,`M,)$#'1"0T`````,=$)"P``````<B+3"0XB40D,(M$)#C'1"0\````
M`,=$)$0`````P>$>#ZS0`HGZB<6+1"1("<V+3"0H`X0D.`(``(EL)#@%W+P;
MCPGI(>LA\0G9BUPD-(E,)$"+3"0P`T0D0`^LV1N)3"1`BTPD,,=$)$0`````
MBWPD1,=$)$P`````QT0D7`````#!X06)3"1(BTPD0`M,)$C'1"0L``````'(
MBTPD,(E$)$")\`^LT`*+5"0TP>8>B<.+1"0H"?,#A"1``@``B=Z)7"1(!=;!
M8LHQ[C'QBW0D0`'(#ZS^&XM\)$")\<'G!0GY`<B+3"0P,?^)QHM$)#")^\'A
M'@^LT`*+5"1$B<6+1"0X"<V+3"1``X0D2`(``(EL)%@%UL%BRC-L)$@QZ0'(
MB?$/K-D;B4PD*(GQP>$%B4PD,(M,)"@+3"0P`<B+3"1`B40D*(M$)$#!X1X/
MK-`"B?J)Q0G-B6PD0(M$)$@#A"10`@``BUPD+,=$)#0`````BWPD-`76P6+*
M,VPD6,=$)$0`````QT0D/`````")Z3'Q`<B+3"0HQT0D3``````/K-D;B4PD
M,(M,)"C!X06)3"0XBTPD,`M,)#@!R(M,)"B)1"0PB?`/K-`"BU0D+,'F'HG#
MBT0D6`GSBW0D0`.$)%@"``")7"0X!=;!8LHQWC'QBW0D,`'(#ZS^&XM\)#")
M\<'G!0GY`<B+3"0H,?^)QHM$)"B)^\'A'@^LT`*)Q8M$)$`)S8M,)#`#A"1@
M`@``B6PD2`76P6+*,VPD.#'I`<B)\0^LV1N)3"0HB?&+5"0TP>$%B4PD0(M,
M)"@+3"1`QT0D+`````"+7"0LQT0D-``````!R(M,)#")1"0HBT0D,,=$)$0`
M````QT0D/`````#!X1X/K-`"B?J+?"0TB<6+1"0X"<T#A"1H`@``B6PD0`76
MP6+*,VPD2(GI,?$!R(M,)"@/K-D;B4PD,(M,)"C!X06)3"0XBTPD,`M,)#@!
MR(M,)"B)1"0PB?`/K-`"BU0D+,'F'HG#BT0D2`GSBW0D0`.$)'`"``")7"0X
M!=;!8LHQWC'QBW0D,`'(#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$)"B)
M^\'A'@^LT`*)Q0G-B6PD2(M$)$`#A"1X`@``BTPD,(M4)#0%UL%BRC-L)#C'
M1"0L`````,=$)#0`````,>D!R(GQ#ZS9&XM<)"R)3"0HB?'!X06)3"1`BTPD
M*`M,)$#'1"1,`````,=$)$0``````<B+3"0PB40D*(M$)##'1"0\`````,'A
M'@^LT`*)^HM\)#2)Q8M$)#@)S0.$)(`"``");"1`!=;!8LHS;"1(B>DQ\0'(
MBTPD*`^LV1N)3"0PBTPD*,'A!8E,)#B+3"0P"TPD.`'(BTPD*(E$)#")\`^L
MT`*+5"0LP>8>B<.+1"1("?.+="1``X0DB`(``(E<)#@%UL%BRC'>,?&+="0P
M`<@/K/X;BWPD,(GQP><%"?D!R(M,)"@Q_XG&BT0D*(G[P>$>#ZS0`HG%"<V)
M;"1(BT0D0`.$))`"``"+3"0PBU0D-`76P6+*,VPD.,=$)"P`````QT0D-```
M```QZ0'(B?$/K-D;BUPD+(E,)"B)\<'A!8E,)$"+3"0H"TPD0,=$)$P`````
MQT0D1``````!R(M,)#")1"0HBT0D,,=$)#P`````P>$>#ZS0`HGZBWPD-(G%
MBT0D.`G-`X0DF`(``(EL)$`%UL%BRC-L)$B)Z3'Q`<B+3"0H#ZS9&XE,)#"+
M3"0HP>$%B4PD.(M,)#`+3"0X`<B+3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$
M)$@)\XMT)$`#A"2@`@``B5PD.`76P6+*,=XQ\8MT)#`!R`^L_AN+?"0PB?'!
MYP4)^0'(BTPD*#'_B<:+1"0HB?O!X1X/K-`"B<4)S8EL)$B+1"1``X0DJ`(`
M`(M,)#"+5"0T!=;!8LHS;"0XQT0D+`````#'1"0T`````#'I`<B)\0^LV1N+
M7"0LB4PD*(GQP>$%B4PD0(M,)"@+3"1`QT0D3`````#'1"1$``````'(BTPD
M,(E$)"B+1"0PQT0D/`````#!X1X/K-`"B?J+?"0TB<6+1"0X"<T#A"2P`@``
MB6PD0`76P6+*,VPD2(GI,?$!R(M,)"@/K-D;B4PD,(M,)"C!X06)3"0XBTPD
M,`M,)#@!R(M,)"B)1"0PB?`/K-`"BU0D+,'F'HG#BT0D2`GSBW0D0`.$)+@"
M``")7"0X!=;!8LHQWC'QBW0D,`'(#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)
MQHM$)"B)^\'A'@^LT`*)Q0G-B6PD2(M$)$`#A"3``@``BTPD,(M4)#0%UL%B
MRC-L)#C'1"0L`````,=$)$P`````,>D!R(GQ#ZS9&XM<)"R)3"0HB?'!X06)
M3"1`BTPD*`M,)$#'1"0T`````,=$)$0``````<B+3"0PB40D*(M$)##!X1X/
MK-`"B?J)Q8M$)#@)S0.$),@"``");"0P!=;!8LHS;"1(B>DQ\0'(BTPD*`^L
MV1N)3"1`BTPD*,'A!8E,)#B+3"1`"TPD.`'(,=N)P8GP#ZS0`HG?P>8>B<6+
M1"1("?6+="0H`X0DT`(``(EL)$`%UL%BRC-L)#`Q[@'PB<X/K/X;B<^)="0X
MP><%BW0D.(E\)$B+5"0L"W0D2,=$)"P`````QT0D/``````!\#'_B<:+1"0H
M#ZS0`HG:B40D2(M$)"C!X!X+1"1(B40D.(G(#ZS0`L'J`HE$)$B)R(E4)$R)
MVHM<)#@/I,(>P>`>B40D6(M$)#`#A"38`@``B50D7`76P6+*,UPD0#'+B?&)
M7"0HB?L#1"0H#ZS9&\'K&XE,)"B)\8E<)"R)^P^DRP7!X06)3"0PBTPD*`M,
M)#")7"0T`<B)P8M$)%0#3"0@B0C'0`0`````BT0D&(M,)%0!\(E!"(M$)$@+
M1"18`T0D$,=!#`````#'010`````B4$0BT0D.`-$)`C'01P`````QT$D````
M`(E!&(M$)$`#!"2)02"!Q.0"``!;7E]=PXVT)@````"-O"<`````55=64XG#
M@^PLA<")5"0<=$JA0$X%"(7`B40D&'0]#[8#/#UU0S'MBT0D&(LP,<"%]G0J
MBWPD&)");"0(B5PD!(DT).BHV/__A<!U!H`\+CUT-H/'!(LWA?9UW3'`@\0L
M6UY?7<.-=@"$P'2YB=V#Q0$/MD4`/#UT!(3`=?$IW>NFC;0F`````(M$)!PK
M?"08P?\"B3B#Q"R-1"X!6UY?7</K#9"0D)"0D)"0D)"0D)"#[!R-5"0,Z$3_
M__^#Q!S#4XG#@^P8C50D#(G8Z"____^%P'0VC78`BQ5`3@4(BT0D#(T$@HM0
M!(72B1!TV&:0@\`$BU`$A=*)$'7TC50D#(G8Z/G^__^%P'7-@\086\-64X/L
M%*%(3@4(B00DZ.[7__^+@'`!``"+<`2A2$X%"(D$).C8U___#[:8^`(``*%(
M3@4(@^-_B00DZ,'7__^+0`0/MT`0P>`'"=AFB48"H4A.!0B)!"3HI-?__XN`
M<`$``(M8!*%(3@4(B00DZ([7___'1"0(`````,=$)`2/X@0(B00DZ.;5__^)
M0QRA2$X%"(D$).AFU___BX!P`0``BU@$H4A.!0B)!"3H4-?__XN`^`,``(E#
M(*%(3@4(B00DZ#K7__^+@'`!``"+6`2A2$X%"(D$).@DU___,=*+B!@&``"%
MR706H4A.!0B)!"3H"]?__XN`&`8``(M0<*%(3@4(B5,DB00DZ/+6__^+@'`!
M``"+0`3'0"@`````H4A.!0B)!"3HU=;__XN`<`$``(M`!,=`&`````"A2$X%
M"(D$).BXUO__BX!P`0``BU@$H4A.!0B)!"3HHM;__XN`>`$``(E#+(/$%%M>
MPXUV`('LC````(7`B;PDA````(G'B5PD?(FT)(````")K"2(````=`6`.`!U
M)HM<)'R+M"2`````B[PDA````(NL)(@```"!Q(P```##C;8`````B00DZ'C6
M__^%P(G&=,QFD(DT).CHU?__A<")PP^$E@```(![$RX/A*0```")/"2#PQ/H
M.=3__XD<)(G%Z"_4__^-1`4"B00DZ,/3__^)7"0,B7PD",=$)`2PX`0(B<6)
M!"3HB=7__XU$)!")1"0(B6PD!,<$)`,```#HL=7__X/X_W00BT0D("4`\```
M/0!```!T9(DL).BDTO__B2PDZ`S2__^)-"3H5-7__X7`B<,/A6S___]FD(DT
M).BPU?__B3PDZ"C2___I#?___XUV`(![%``/A#;___^`>Q0N9I`/A4;___^`
M>Q4`#X0@____Z3?___^-=@")Z.BQ_O__D.N:C;0F`````(V\)P````!6B<93
M,=N#[!2A2$X%"(D$).@:U?__B70D!,<$)`,```"#P%R)1"0(Z!/5__^%P'0/
M@\04B=A;7L.-M"8`````H4A.!0B)!"3HX]3__XM`;"4`\```/0!```!T'*%(
M3@4(B00DZ,?4__^+0&PE`/```#T`H```=;F)-"0QV\=$)`0"````Z/;3__^%
MP`^4PX/$%(G86U[#B?:-O"<`````55=6B<93,<"#[#R)TX`Z/0^4P`'#B1PD
MZ*/2__^-5"0LB40D'(GPZ%3[__^%P(G'#X3J````B00DZ(+2__\QTCE$)!P/
MAK8```"+3"0LP>$"#[8&/#T/A'0!``"$P`^$;`$``(GPZP2$TG0+@\`!#[80
M@/H]=?$I\(M4)!R+/4!.!0B-1!`"`<^)!"3HS]'__X7`B0</A#P!``"+5"0L
MH4!.!0B+!)`/MA:$TH@0="2`^CUT'X/&`>L+C;8`````@/H]=`\/MA:#P`&#
MQ@&$TH@0=>S&`#TQTHVT)@`````/M@P3B$P0`8/"`83)=?$QP(/$/%M>7UW#
MC;0F``````^V!!.(!!>#P@&$P'3A#[8$$X@$%X/"`83`=>3KT6:0BRU`3@4(
M,?^X"````(M5`(72=!:-="8`@\<!BTR]`(7)=?6-!+T(````BQ6`3@4(A=)T
M-(E$)`2)+"3H\-#__X7`B<*C0$X%"'1LC0R]`````,=$N@0`````B7PD+.G.
M_O__D(UT)@#'!8!.!0@!````B00DZ,;0__^%P'0YC0R]`````(E,)`B)3"04
MB6PD!(D$)(E$)!CH,\___XM4)!B+3"04B15`3@4(ZZ6-=@`QP.FB_O__N/__
M___I$/___^L-D)"0D)"0D)"0D)"0D('L/!```(F\)#00``"-?"0<B9PD+!``
M`(G#B:PD.!```(G59:$4````B80D'!```#'`B;0D,!```,=$)`C_#P``B7PD
M!,<$)+;@!`CH?\___X7`#XZ'````C7#_@'PT'`!T=8G&B70D",=$)`0O````
MB3PDZ!?1__^%P'1CH4A.!0B)!"3H%M+__XET)`R)?"0(B5PD!(D$).B2T?__
MBX0D'!```&4S!10```!U48N<)"P0``"+M"0P$```B[PD-!```(NL)#@0``"!
MQ#P0``##C;0F`````(7V=8F-="8`H4A.!0B)!"3HL]'__XEL)`B)7"0$B00D
MZ./.___KG^A\SO__C;8`````C;\`````@^P<H4A.!0B)!"3H@-'__\=$)`S%
MX`0(QT0D"`"6!`C'1"0$S^`$"(D$).CPS___@\0<PXVV`````(V_`````(/L
M+*%(3@4(B00DZ$#1__^)!"3HJ/___Z%(3@4(B00DZ"O1___'1"04`````,=$
M)!"/X@0(QT0D#(_B!`C'1"0(T-H$",=$)`3KX`0(B00DZ#O0__^#Q"S#C;0F
M`````('L+"```(F<)"`@```QVXFT)"0@``"-="0:9:$4````B80D'"```#'`
MB;PD*"```.A;SO__QT0D#,'@!`C'1"0$`.$$"(DT)(E$)`CH3]#__X7`>$:-
MO"0;$```B30DQT0D"``0``")?"0$Z+#-__^%P(G&>"6-0`&)!"3H/\[__X7`
MB<-T%(ET)`B)?"0$B00DZ-G,___&!#,`BY0D'"```&4S%10```")V'4<BYPD
M("```(NT)"0@``"+O"0H(```@<0L(```P^@"S?__9I#I*____XUT)@"-O"<`
M````55=64X'L3!```&6A%````(F$)#P0```QP+@.X00(BYPD8!```(NT)&00
M``#H?_?__\=$)`0O````B1PDB<7HW<W__X7`="V)VK@7X00(Z"W[__^+E"0\
M$```93,5%````(G8#X5&`0``@<1,$```6UY?7<.)'"3HQ,W__\=$)`0DX00(
MB30DB40D+.C@SO__A<")QW2QC70D/(VV`````(`_`'4%OPSA!`B%[704B7PD
M!(DL).B&R___A<`/A)L```")/"3H=LW__X!\!_\O=16-M"8`````@^@!@'P'
M_R_&!`<`=/*+5"0LC400`3W_#P``#X].____B5PD$,=$)`PFX00(B7PD",=$
M)`1%X@0(B30DZ*?.__^A2$X%"(D$).CJSO__B70D!,<$)`,```"#P%R)1"0(
MZ,/.__^%P'4<H4A.!0B)!"3HPL[__XM`;"4`\```/0"```!T(\=$)`0DX00(
MQP0D`````.C_S?__A<")QP^%)?___^G'_O__QT0D!`$```")-"3HT,W__X7`
M=<F)\K@7X00(Z.#Y__^)-"3H*,W__XG#Z:3^___H/,O__XVV`````(V_````
M`(M$)`0/M@B$R70BC5`!ZPN#P@$/MDK_A,ET$H#Y+W7PB="#P@$/MDK_A,EU
M[O/#D%.#[!B+7"0@A=MT+(`[`'0GB1PDZ#?,__^-1`/_.<-R#NM!D(UT)@"#
MZ`$YV'1Y@#@O=/3K)V:0QP0D`@```.BLR___A<!T!6;'`"X`@\086\.-M@``
M``"`."]T!X/H`3G#<O0YV'1`@^@!.<-S!8`X+W3TB<(QP"G:C4H"@?D`$```
M=\B#P@&)7"0$B50D",<$)*!.!0CHE,S__X/$&+B@3@4(6\-FD(`X+W01QT0D
M(";A!`B#Q!A;Z2+,___'!"0"````Z";+__^)PC'`A=(/A'?___]FQP(N`(G0
MZ6O___^-M"8`````C;PG`````%=6@^PT9:$4````B40D+#'`H9SB!`B)1"0*
MH:#B!`B)1"0.H:3B!`B)1"02H:CB!`B)1"06H:SB!`B)1"0:H;#B!`B)1"0>
MH;3B!`B)1"0BH;CB!`B)1"0F#[<%O.($"&:)1"0JN"CA!`CH<?3__[@QX00(
MZ&?T__^X.>$$".A=]/__N$+A!`CH4_3__[A)X00(Z$GT__^X6>$$".@_]/__
MN`[A!`CH-?3__[AEX00(Z"OT__^X;^$$".@A]/__N'GA!`CH%_3__[@7X00(
MZ`WT__^X@^$$".@#]/__N(SA!`CH^?/__[B7X00(Z-_S__^%P'0,B<*X;^$$
M".B?]___N*CA!`CHQ?/__X7`=`R)PKBZX00(Z(7W__^XQ>$$".BK\___A<!T
M+XG"N`[A!`CH:_?__[KQX00(N$GA!`CH7/?__XM$)"QE,P44````=4F#Q#1>
M7\.0N-7A!`CH;O/__X7`=!*)PKAEX00(Z"[W___KP8UT)@"-="0;O^;A!`BY
M"@```/.F=:N-5"0EN&7A!`CH"/?__^N;Z''(__^0@^P,H6#R!`B#^/]T"X/$
M#,.-M"8`````N&7A!`CH#O/__XG",<"%TG0/#[82A-)T"#'`@/HP#Y7`HV#R
M!`B#Q`S#C;0F`````(V\)P````"#[!SH*,C__XD$).B`Q___A<!T#(L`@\0<
MPXVV`````#'`Z_*-M@````"-OP````!55U93N_WA!`B#[%R+?"1PC70D.,=$
M)#3]X00(QT0D.//A!`C'1"0\`.($",=$)$#VX00(QT0D1/OA!`C'1"1(#>($
M",=$)$P`````ZQQFD(E\)`2)!"3HU,;__X7`=#B#Q@2+7OR%VW0EB=CH/_+_
M_X7`B<5T!8`X`'74B=B#Q@2)^NCX]?__BU[\A=MUVX/$7%M>7UW#D(D\).B@
MR/__B2PDB40D+.B4R/__BU0D+(U$`@*)!"3H),C__XEL)!#'1"0,).$$"(E\
M)`C'1"0$1>($"(D$)(E$)"SHX,G__XM4)"R)V.B5]?__Z7#___]55U93@>P\
M@0``9:$4````B80D+($``#'`N`[A!`B+G"10@0``QT0D6"3B!`C'1"1<#.$$
M",=$)&``````QT0D0+KA!`C'1"1$L^$$",=$)$@IX@0(QT0D3-#A!`C'1"10
M,>($",=$)%0`````QT0D9!CB!`C'1"1H->($",=$)&P`````Z#;Q__^%P'0)
M@#@`#X79`P``Z$3^__^%P(G%#X3K`P``#[95`(32="J(5"0DZ+G)__\/ME0D
M)(GI9I"+,`^^TO8$5@AU`\8!7X/!`0^V$832=>B-?"1$N+KA!`CK#Y"-="8`
M@\<$BT?\A<!T+NC)\/__A<")QG3K@#@`=.;HZ?/__X7`=-V)-"3HS<?__X7`
MB<=U4(VT)@````"+="18,?^%]G0_@#X`N`$```!T-8G'ZQB+=+Q8A?8/A%P!
M``"#QP&`/@`/A%`!``")\.B9\___A<!TW8DT).A]Q___A<!TT8G'B3PDZ-_&
M__^)+"2)QNC5QO__C;0&!`0``(DT).AFQO__B6PD%,=$)!`^X@0(QT0D#";A
M!`B)?"0(QT0D!$/B!`B)1"0TB00DZ!K(__^+1"0TQT0D!,`!``")!"3H!L?_
M_X/X_P^$A0```*%(3@4(B00DZ$#(___'!"0#````@\!<B40D"(M$)#2)1"0$
MZ#7(__^%P`^$I0```(M$)#2)1"0,BP/'1"0$_.($"(E$)`BA1$X%"(D$).A*
MQO__QT0D.`````"+E"0L@0``93,5%````(M$)#@/A3H)``"!Q#R!``!;7E]=
MPXVT)@````#HH\;__XL`@_@1#X1K____B40D$(M$)#2)1"0,BP/'1"0$P.($
M"(E$)`BA1$X%"(D$).CAQ?__QT0D.`````#KE8VT)@`````Q_^G"_O__D*%(
M3@4(B00DZ&O'__^+0&PE`/```#T`0```#X4[____H4A.!0B)!"3H2\?__XMX
M=.@SQ/__.<</A1[___^A2$X%"(D$).@NQ___BT!L)?\!```]P`$```^%_O[_
M_XDT).CCQ/__B40D.+CVX00(Z*7N__^%P`^$LP$``(D$).BUQ?__B40D!(L#
MB00DZ-?V__^%P(G%#X23`0``B2PDZ`7%__^#^`-^*(UT!?R_3.($"+D%````
M\Z9U%H/X!`^$%`<``(!\!?LO#X0)!P``9I#H$_O__X7`=1S'1"0$`````(DL
M).COQ/__A<")1"0\#X5``0``NO'A!`BX9>$$".CD\?__,=OH#<3__\=$)!2/
MX@0(QT0D#";A!`C'1"0$:N($"(E$)!"+1"0TB40D"(M$)#B)!"3H[<7__XMT
M)#B+?"0TZT&-=@#H"\7__X,X$75)Z,'#__^#PP''1"08C^($"(E<)!3'1"0,
M)N$$"(E\)`C'1"0$>.($"(E$)!")-"3HHL7__\=$)`3``0``B30DZ)+$__^#
M^/]TK8M$)#2)!"3H0<+__XM4)#BX#N$$".@S\?__BT0D.(D$).BG^O__Z<#]
M__]FD(D$)(E$)"3HE/K__XM$)"2)!"3H6,3__XE$)#CIG?W__[X!````N!CB
M!`CK#HUV`(M$M&2#Q@&%P'0AZ!#M__^%P'3L@#@`=.>)!"3H'\3__X7`=-N)
MQ>G:^___O1WB!`CI`OS__XLKZ6;^___'1"0,`@```,=$)`3N____QT0D"/__
M__^)!"3HL\+__XM$)#R-5"1PQT0D"`8```")5"0$B00DZ$?!__^`?"1P`'4+
M@'PD<4,/A-(%``"+1"0\QT0D#`````#'1"0$`````,=$)`@`````B00DZ&'"
M___'A"1P@````2-%9\>$)'2`````````QX0D>(```(FKS>_'A"1\@```````
M`,>$)("```#^W+J8QX0DA(````````#'A"2(@```=E0R$,>$)(R`````````
MQX0DD(```/#ATL/'A"24@````````,>$))B`````````QX0DG(````````#'
MA"2@@````````,>$)*2`````````QX0DZ(````````"-="8`BT0D/(U\)'#'
M1"0(`(```(E\)`2)!"3H3,#__X7`B<,/CIX!``"+A"28@```B=^)WHN4))R`
M``#!_Q^)1"0HB=B)5"0LP>`#`T0D*(-\)"P`=P8Y1"0H=A"#A"2@@````8.4
M)*2`````B80DF(```(N$).B````/K/X=P>\=`;0DH(```!&\)*2```"-5"1P
MA<#'A"2<@````````(V\)*B```")5"0H=%ZZ0````(G>*<(YTWX"B=:-O"2H
M@````?B-5"1PB70D"(E4)`2)!"3HTK___XN$).B````!\(/X0(F$).B````/
MA1'___^-5"1P*?,!\HV$)'"```")5"0HZ"'&__^0@_L_#XZ3````BW0D*(G=
MD(L&@^U`B0>+1@2)1P2+1@B)1PB+1@R)1PR+1A")1Q"+1A2)1Q2+1AB)1QB+
M1AR)1QR+1B")1R"+1B2)1R2+1BB)1RB+1BR)1RR+1C")1S"+1C2)1S2+1CB)
M1SB+1CR#QD")1SR-A"1P@```Z*#%__^#_3]_BX/K0(G:P>H&C4(!P>`&`40D
M*,'B!BG3BU0D*(E<)`B)/"2)5"0$Z/"^__^)G"3H@```Z3S^__^+1"0\B00D
MZ'C"__^+A"2@@```BY0DI(```(N<))B```"+M"2<@```B40D*(E4)"R)V(GR
M#ZS0`X/@/XU0`8/Z.,:$!*B```"`#X^M`@``NC<````IPHV$!*F```")5"0(
MQT0D!`````")!"3HD\#__XM4)"R+1"0HB)PDYX````^LT!B+5"0LB(0DX(``
M`(M$)"@/K-`0BU0D+(B$).&```"+1"0H#ZS0"(GRB(0DXH````^V1"0HB(0D
MXX```(G8#ZS0&(GRB(0DY(```(G8#ZS0$(GRB(0DY8```(G8,=L/K-`(B(0D
MYH```(V$)'"```#H;,3__XNT)'"```"+O"1T@```B?")^@^LT!B)^HG!B(0D
M&($``(GP#ZS0$(GZB[PD?(```(B$)!F!``")\`^LT`B)\HNT)'B```"(A"0:
M@0``B)0D&X$``(GZB?`/K-`8B?J(A"0<@0``B?`/K-`0B?J+O"2$@```B(0D
M'8$``(GP#ZS0"(B$)!Z!``")\(NT)("```")^HB$)!^!``")\`^LT!B)^HB$
M)""!``")\`^LT!")^HN\)(R```"(A"0A@0``B?`/K-`(B?*+M"2(@```B(0D
M(H$``(B4)".!``")^HGP#ZS0&(GZB(0D)($``(GP#ZS0$(GZB[PDE(```(B$
M)"6!``")\`^LT`B(A"0F@0``B?"+M"20@```B?J(A"0G@0``B?`/K-`8B?J(
MA"0H@0``B?`/K-`0B?J(A"0I@0``B?`/K-`(B?*(A"0J@0``C;0D[X```(G(
MB)0D*X$``.D(````#[:$'!B!```/ML")1"0(C01>@\,!QT0D!&7B!`B)!"3H
MD[___X/[%'76QH0D%X$```#'1"04C^($"(ET)!"+1"0TQT0D#";A!`C'1"0$
M5N($"(E$)`B+1"0XB00DZ%:____IQ/G__XM;!(7;#X3N^/__B1PDZ+Z]__^#
M^`,/AMWX__^-=`/\OU'B!`BY!0```/.F#X7'^/__B=WIP/C__[H_````*<*-
MA`2I@```B50D",=$)`0`````B00DZ.:]__^-A"1P@```Z#K"__^-E"2H@```
MN0X````QP(G7\ZOI,/W__X!\)')!#X4C^O__@'PD<T,/A1CZ__^`?"1T2`^%
M#?K__X!\)'5%#X4"^O__BT0D/,=$)`P"````QT0D!,;____'1"0(_____XD$
M).ACO/__BT0D/(U4)'")5"0$QT0D""D```")!"3H][K__XU4)'#'1"04C^($
M"(E4)!#IV/[__V:0Z'N[__^-="8`C;PG`````%575E.#[!RA2$X%"(D$).A\
MOO__QH#Y`@```;A)X00(Z`OF__^%P'0)@#@Q#X2>`@``Z"GQ__^A2$X%"(D$
M).A,OO__QT0D#`L```#'1"0(`0```,=$)`2)X@0(B00DZ`R\__^%P`^$Q```
M`(M`##'VBV@8H:1>!0B#^`$/CJ,```"[`0```.LQC;0F`````(M'#(E$)`2A
MH%X%"(L$F(D$).@9NO__A<!U=:&D7@4(@\,!@\8!.=A^:Z%(3@4(B00DZ,F]
M___'1"0,`````(ET)`B);"0$B00DZ"&]__^%P'0]BSCV1PD$=:6A2$X%"(D$
M).B8O?__QT0D#`(```#'1"0(`````(E\)`2)!"3HS+K__^EZ____C;0F````
M`*&D7@4(C5#_.?(/A$`!``"A2$X%"(D$).A3O?__QT0D#`0```#'1"0(`0``
M`,=$)`2.X@0(B00DZ!.[__^%P(G#=#6+0`R+,*%(3@4(B00DZ!N]___'1"0(
MD.($"(ET)`2)!"3H1[K__XM##(L8]D,*0`^%&`$``*%(3@4(B00DZ.N\___'
M1"0,!````,=$)`@!````QT0D!)7A!`B)!"3HJ[K__X7`B<-T-K@7X00(Z%OD
M__^%P(G&#X1Y`0``BT,,BSBA2$X%"(D$).B?O/__B70D"(E\)`2)!"3HS[G_
M_Z%(3@4(B00DZ(*\___&@/D"````H4A.!0B)!"3H;KS__\>`<`0```````"X
M#N$$".CZX___A<"CJ%X%"`^$I0```,=$)`3``0``B00DZ.VZ__^#^!%T#H7`
M=`J#^/^0#X6!`0``@\0<6UY?7<-FD(/X`0^.M_[__[L!````9I"A2$X%"(/#
M`8D$).@`O/__B6PD!(D$).B$N/__.1VD7@4(?]SIA_[__XVT)@````"A2$X%
M"(D$).C3N___B5PD!(D$).CGNO__Z<K^__]FD(!X`0`/A%W]__^-M@````#I
M3?W__XUV`*&@7@4(B00DZ'OQ__^%P*.H7@4(#X39````BT,,BSV@7@4(BS#V
M1@D$=&R+1@R)?"0$B00DZ(ZX__^)QHM##(L8]D,)!'1^BT,,B40D"*&@7@4(
MB70D#(L`QP0D=.,$"(E$)`3HO[G__XVT)@````"AH%X%"(LXBT,,BS"A2$X%
M"(D$).@?N___B?J)\.AVZ/__Z8+^__^A2$X%"(D$).@$N___QT0D#`(```#'
M1"0(`````(ET)`2)!"3H.+C__^EI____H4A.!0B)!"3HUKK__\=$)`P"````
MQT0D"`````")7"0$B00DZ`JX___I5____\<$)%#C!`CH*;G__XE$)`RAJ%X%
M"(E$)`BAH%X%"(L`QP0DG.,$"(E$)`3H!;G__Y"-="8`5E.#[!2+="0@B30D
MZ$_L__\/MA")PX32=".-0`'K#)"#P`$/ME#_A-)T$H#Z+W7PB<.#P`$/ME#_
MA-)U[NBN[O__A<!T((7V=!R`/@"-=@!T%,=$)`0^X@0(B1PDZ#ZV__\YV'0&
M@\046U[#@\04B?!;7NEXX___D(VT)@````"#[!RA2$X%"(D$).CPN?__QT0D
M!/____^)!"3H4+?__Z%(3@4(B00DZ-.Y___'1"0(`````,=$)`1@P00(B00D
MZ(NY__^#Q!S#D)"0D)"0D%6)Y5/H,@```('#5Q$``(/L$(N#-`$``(E$)`R+
M11")1"0(BT4,B40D!(M%"(D$).C[MO__@\006UW#BQPDPY!5B>5=PXUT)@"-
MO"<`````58GE5U93Z.#___^!PP41``"#[!SH&[7__XV[\/[__XV#\/[__RG'
MP?\"A?]T)#'VBT40B40D"(M%#(E$)`2+10B)!"3_E+/P_O__@\8!.?YRWH/$
M'%M>7UW#D)"0D)"058GE4X/L!*$`\`0(@_C_=!.[`/`$"&:0@^L$_]"+`X/X
M_W7T@\0$6UW#D)!5B>53@^P$Z`````!;@<-X$```Z"R[__]96\G#`P````$`
M`@`E<R\E<P`O<')O8R]S96QF+V5X90!P97)L>'-I+F,`1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I
M+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),
M3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%2
M7T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%2
M7T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%4
M2`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`'!A<BT`
M)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM``!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T
M:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``````````````````@/___\]!`1L#.]@````:````@+'___0```#0
MM?__8`4``'"X__\8`0``8-S__U@!```0W?__K`$``"#=___$`0``<-W__^@!
M``#@WO__%`(``$#@__]``@``X.#__W@"``#0XO__N`(``.#C___D`@``(.3_
M__P"``"`Y/__%`,``%#E__\\`P``8.7__U`#```@Y___D`,``%#G__^D`P``
M0.C__^`#``#@Z?__$`0``##J__\P!```8.K__TP$``!0Z___C`0``.#V___0
M!```\/K__Q`%``!P^___2`4``!0``````````7I2``%\"`$;#`0$B`$``"``
M```<````A+#__U`$````#@A&#@Q*#PMT!'@`/QH[*C(D(CP```!`````4+?_
M_^(C````00X(A0)##@R'`T0.$(8$00X4@P5(#O@%`\PC#A1!#A##00X,QD$.
M",=!#@3%``!0````@`````#;__^A`````$$."(4"00X,AP-!#A"&!$$.%(,%
M10Y``E<*#A1!#A##00X,QD$.",=!#@3%1`MP#A1%PPX00<8.#$''#@A!Q0X$
M```4````U````%S;__\0`````$,.($P.!``@````[````%3;__]0`````$$.
M"(,"10X@`D@."$$.!,,````H````$`$``(#;__]M`0```$$."(8"00X,@P-#
M#B`#90$.#$$.",-!#@3&`"@````\`0``Q-S__U(!````1@Z0`4N'`U2%`H8$
M@P5D"@X$Q<?&PT<+````-````&@!``#XW?__EP````!!#@B&`D,.#(,#10X@
M:PH.#$,.",-!#@3&2`L"4@X,0\,."$'&#@0\````H`$``&#>___A`0```$$.
M"(4"00X,AP-!#A"&!$,.%(,%10Y0`ND*#A1!#A##00X,QD$.",=!#@3%2`L`
M*````.`!```0X/__!`$```!&#L`@2X<#28,%284":88$`H0*#@3%Q\;#2`L4
M````#`(``/3@__\T`````$,.('`.!``4````)`(``!SA__]9`````$,.,`)5
M#@0D````/`(``&3A___.`````$8.L$!)@P1+A@-6AP("F`H.!,?&PT$+$```
M`&0"```,XO__!0`````````\````>`(```CB__^T`0```$$."(4"00X,AP-!
M#A"&!$$.%(,%1@[@(`)E"@X400X0PT$.#,9!#@C'00X$Q4$+$````+@"``"(
MX___+P`````````X````S`(``*3C___B`````$$."(,"0PX@`DP*#@A!#@3#
M1PL"1PH."$;##@1#"U`*#@A!#@3#10L````L````"`,``%CD__^?`0```$$.
M"(<"00X,A@-##D`#3P$*#@Q!#@C&00X$QT(+```<````.`,``,CE__]"````
M`$,.$$T*#@1("VD.!````!@```!8`P``^.7__R0`````0PX@5@H.!$<+```\
M````=`,```SF___P`````$$."(4"00X,AP-!#A"&!$$.%(,%2`YP`H8*#A1!
M#A##00X,QD$.",=!#@3%0@L`0````+0#``"\YO__A0L```!!#@B%`D$.#(<#
M00X0A@1!#A2#!48.T(("`T(""@X400X0PT$.#,9!#@C'00X$Q4@+```\````
M^`,```CR__\+!````$$."(4"00X,AP-!#A"&!$$.%(,%0PXP`V(""@X400X0
MPT$.#,9!#@C'00X$Q4,+-````#@$``#8]?__>`````!!#@B&`D$.#(,#0PX@
M`F0*#@Q!#@C#00X$QD$+0PX,0PX(PT$.!,84````<`0``"#V__])`````$,.
M(`)%#@0H````B`0``&BP___B`0```$$."(4"0@T%7(,$A@,#9P$*PT'&00P$
M!,5!"P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````/____\`````_____P```````````0````$````!````SP$```$`
M``#:`0```0```.0!```!````,P(```$```!^`P``#````#25!`@-````C.`$
M"`0```",@00(]?[_;[B$!`@%````D(P$"`8````0A@0("@```/0$```+````
M$````!4``````````P```!#Q!`@"````(`(``!0````1````%P```!23!`@1
M````Y)($"!(````P````$P````@```#^__]O5)($"/___V\"````\/__;X21
M!`@`````````````````````````````````````````````````````````
M````````````%/`$"```````````AI4$"):5!`BFE00(MI4$",:5!`C6E00(
MYI4$"/:5!`@&E@0(%I8$"":6!`@VE@0(1I8$"%:6!`AFE@0(=I8$"(:6!`B6
ME@0(II8$"+:6!`C&E@0(UI8$".:6!`CVE@0(!I<$"!:7!`@FEP0(-I<$"$:7
M!`A6EP0(9I<$"':7!`B&EP0(EI<$"*:7!`BVEP0(QI<$"-:7!`CFEP0(]I<$
M"`:8!`@6F`0()I@$"#:8!`A&F`0(5I@$"&:8!`AVF`0(AI@$"):8!`BFF`0(
MMI@$",:8!`C6F`0(YI@$"/:8!`@&F00(%ID$"":9!`@VF00(1ID$"%:9!`AF
MF00(=ID$"(:9!`B6F00(IID$"+:9!`@`````````````````````````````
M````````````````````````````````````````_____P``````````````
M```````````````````````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P[
M"@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@
M870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE
M.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@
M(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B
M96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@
M(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H
M:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T
M;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA
M=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@
M(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N
M(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M
M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI
M<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN
M9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@
M(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%
M(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^
M("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*
M"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I
M"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE
M;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T
M;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I
M"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"
M14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET
M7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6
M>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%2
M1U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@
M)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6
M*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*
M("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX
M("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@
M*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I
M;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[
M>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L
M(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@
M("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN
M(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@
M9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@
M("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@
M("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@
M("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D
M8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B
M=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@
M("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D
M('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D
M14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@
M)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@
M("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL
M;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@
M/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@
M("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@
M("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@
M("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@
M("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@
M("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E
M96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M
M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E
M='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)
M3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@
M("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@
M<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@
M(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@
M("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M
M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S
M="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L
M97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R
M97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I
M=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C
M97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O
M;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE
M<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M
M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@
M("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A
M<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R
M"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N
M86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B
M+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D
M92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E
M;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE
M;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M
M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O
M7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@
M('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@
M(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@
M("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD
M;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@
M("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A
M8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI
M9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%
M35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@
M("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@
M("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8
M("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T
M(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D
M("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@
M("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@
M("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@
M("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@
M("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*
M("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@
M("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$[
M"B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P
M;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`[
M"B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@
M("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*
M("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H
M+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*
M("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD
M;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC
M*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`
M:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T
M:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*
M("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET
M92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&
M:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@
M("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O
M0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI
M<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T
M:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G
M:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L
M"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F
M:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S
M>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R
M('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@
M("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M
M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA
M7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@
M(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B
M+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0[
M"B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@
M("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG
M+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@
M("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N
M=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@
M("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@
M(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@
M("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@
M("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@
M("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N
M9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*
M("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U
M+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@
M*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^
M861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2
M+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T
M.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R
M;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D[
M"@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O
M(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L
M;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7
M:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@
M("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`
M(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*
M"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@
M(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@
M("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@
M("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@
M("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@
M("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@
M("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@
M("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@
M("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@
M("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*
M("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@
M("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@
M(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]
M"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@
M>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@
M("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S
M96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*
M("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R
M.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@
M("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q
M=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I
M<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E
M<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER
M92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q
M=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER
M92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@
M<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E
M($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@
M=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I
M<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@
M87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@
M(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@
M("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*
M("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64[
M"B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E
M=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U
M:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<[
M"@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY
M("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@
M+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@
M("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES
M<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S
M+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@
M("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN
M($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D
M8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y]
M(#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@
M("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U
M8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M
M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E
M;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@
M("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@
M("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*
M("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL
M96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O
M<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D
M9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P
M4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@
M("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D
M,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*
M("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@
M<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D
M<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA
M;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#
M;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]
M7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@
M("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F
M:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%2
M7U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T
M;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS
M=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*
M("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@
M(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=0
M05)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-
M4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@
M("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@
M("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE
M;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@
M:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B
M(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I
M('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS
M92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I
M;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@
M(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*
M"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA
M9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@
M)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*"C$["@HC;&EN92`Q,#$Q"@I?7T5.1%]?"@````!'0T,Z("A$96)I86X@
M-"XV+C(M-2D@-"XV+C(`1T-#.B`H1&5B:6%N(#0N-"XV+3$P*2`T+C0N-@``
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I
M;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`
M+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`
M+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M```````````+`````0````(````T@00(-`$``!,```````````````$`````
M````$P````<````"````2($$"$@!```@```````````````$`````````"$`
M```'`````@```&B!!`AH`0``)```````````````!``````````X````!0``
M``(```",@00(C`$``"P#```&``````````0````$````-````/;__V\"````
MN(0$"+@$``!8`0``!@`````````$````!````#X````+`````@```!"&!`@0
M!@``@`8```<````!````!````!````!&`````P````(```"0C`0(D`P``/0$
M``````````````$`````````3@```/___V\"````A)$$"(01``#0````!@``
M```````"`````@```%L```#^__]O`@```%22!`A4$@``D`````<````"````
M!`````````!J````"0````(```#DD@0(Y!(``#`````&``````````0````(
M````<P````D````"````%),$"!03```@`@``!@````T````$````"````'P`
M```!````!@```#25!`@T%0``,```````````````!`````````!W`````0``
M``8```!PE00(<!4``%`$`````````````!`````$````@@````$````&````
MP)D$",`9``#,1@`````````````0`````````(@````!````!@```(S@!`B,
M8```'```````````````!`````````".`````0````(```"HX`0(J&```$@#
M``````````````@`````````E@````$````"````\.,$"/!C``#<````````
M```````$`````````*0````!`````@```,SD!`C,9```M`0`````````````
M!`````````"N`````0````,`````\`0(`'````@```````````````0`````
M````M0````$````#````"/`$"`AP```(```````````````$`````````+P`
M```!`````P```!#P!`@0<```!```````````````!`````````#!````!@``
M``,````4\`0(%'```/@````'``````````0````(````R@````$````#````
M#/$$"`QQ```$```````````````$````!````,\````!`````P```!#Q!`@0
M<0``'`$`````````````!`````0```#8`````0````,```!`\@0(0'(``.1;
M`````````````"``````````W@````@````#````0$X%""3.``!P$```````
M```````@`````````.,````!````,``````````DS@``.0``````````````
M`0````$````!`````P``````````````7<X``.P```````````````$`````
#````
